//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of the Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.
//

m = mode();
mode(7);
// Forward dynamics is the computation of joint accelerations given position and
// velocity state, and actuator torques.  It is useful in simulation of a robot
// control system.
//
// Consider a Puma 560 at rest in the zero angle pose, with zero applied joint 
// torques. The joint acceleration would be given by
//

mdl_puma560

accel(p560, qz, zeros(1,6), zeros(1,6))

// To be useful for simulation this function must be integrated.  fdyn() uses the
// MATLAB function ode45() to integrate the joint acceleration.  It also allows 
// for a user written function to compute the joint torque as a function of 
// manipulator state.
//
// To simulate the motion of the Puma 560 from rest in the zero angle pose 
// with zero applied joint torques

p560nf = nofriction(p560);
t = linspace(0,10,205);
tic; [t q qd] = fdyn(p560nf,t, [], qz);toc



// and the resulting motion can be plotted versus time
scf(100001); subplot(3,1,1); plot(t,q(1,:)); xlabel('Time (s)'); ylabel('Joint 1 (rad)');
subplot(3,1,2); plot(t,q(2,:)); xlabel('Time (s)'); ylabel('Joint 2 (rad)');
subplot(3,1,3); plot(t,q(3,:)); xlabel('Time (s)'); ylabel('Joint 3 (rad)');

// Clearly the robot is collapsing under gravity, but it is interesting to 
// note that rotational velocity of the upper and lower arm are exerting 
// centripetal and Coriolis torques on the waist joint, causing it to rotate.
//
// This can be shown in animation also
plot_robot(p560nf,q','perspective');

mode(m);
return;
