//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of the Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.
//

mode(7);
// We will work with a model of the Puma 560 robot
mdl_puma560

// The trajectory demonstration has shown how a joint coordinate trajectory
// may be generated

t = [0:.05:2]'; 	// generate a time vector
q = jtraj(qz, qready, t); // generate joint coordinate trajectory

// the overloaded function plot() animates a stick figure robot moving 
// along a trajectory.
plot_robot(p560,q);

// The drawn line segments do not necessarily correspond to robot links, but 
// join the origins of sequential link coordinate frames.
//
// A small right-angle coordinate frame is drawn on the end of the robot to show
// the wrist orientation.
//
// A shadow appears on the ground which helps to give some better idea of the
// 3D object.
//
// This is a 3D plot so using the tools on the figure toolbar you can rotate the
// figure and change your viewpoint.
//
//--
// We can also place additional robots into a figure.
//
// Let's make a clone of the Puma robot, but change its name and base location

p560_2 = SerialLink(p560, ...
    'name', 'another Puma', ...
    'base', transl(-0.5, 0.5, 0) )

plot_robot(p560_2, q, 'hold');

// We can also have multiple views of the same robot

clf; handle = gcf();
plot_robot(p560,qready);
handle = scf();
handle.tag = "Robot";
plot_robot(p560,qready);
plot_robot(p560,q);

// Sometimes it's useful to be able to manually drive the robot around to
// get an understanding of how it works.

teach(p560);
// Use the sliders to control the robot (in fact both views).  Hit the red quit
// button when you are done.
