//  Copyright (C) 2019 - Corrado Guarino Lo Bianco
//
//  This file is part of the Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

m = mode();
mode(7);
// Load the Unimation Puma 560 manipulator model
mdl_puma560
// The path will move the robot from its zero angle pose to the upright (or 
// READY) pose.
//
// First create a time vector, completing the motion in 2 seconds with a
// sample interval of 56ms.
t = [0:.056:2]';
//
// A polynomial trajectory between the 2 poses is computed using jtraj()
//
[q, qd, qdd] = jtraj(qz, qready, t);
//
// For this particular trajectory most of the motion is done by joints 2 and 3,
// and this can be conveniently plotted using standard Scilab operations
scf(100000); subplot(3,1,1); plot(t, q(:,2:3));xlabel('Time (s)');ylabel('Joint positions (rad)')
subplot(3,1,2); plot(t, qd(:,2:3));xlabel('Time (s)');ylabel('Joint velocities (rad/s)')
subplot(3,1,3); plot(t, qdd(:,2:3));xlabel('Time (s)');ylabel('Joint accelerations (rad/s^2)')
mode(m);
