//  Copyright (C) 2014-20 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function [r] = %s_i_Robot(field, v, r)
disp(field)
    if typeof(field) ~= "string" then

        error("only .field supported");
        
    else
        select field,
            
        case "gravity" then
            if length(v) == 3 then
                r.gravity = v;
            else
                error("gravity must be a 3-elements vector");
            end

        case "base" then
            if ~ishomog(v) then
                error("base must be a homogeneous transform");
            else
                r.base=v;
            end

        case "tool" then
            if ~ishomog(v) then
                error("tool must be a homogeneous transform");
            else
                r.tool=v;
            end

        case "offset" then
            L = r.links;
            for i=1:r.n
                L(i).offset = v(i);
            end
            r.links = L;

        case "qlim" then
            if numrows(v) ~= r.n
                error('insufficient rows in joint limit matrix');
            end
            L = r.links;
            for i=1:r.n
                L(i).qlim = v(i,:);
            end
            r.links = L;
      
        case "q" then
            if isempty(v) | and(size(v) == [r.n, 1]) | and(size(v) == [1, r.n]) then
                    r.q=v;
                else
                    error("insufficient rows in joint vector");
                end
        case "n" then
                error("robot.n is read only variable");
        else
            error("unknown method");
        end
    end

endfunction
