//  Copyright (C) 2014-20 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function updateSlider(r, b)
	
    [%nargout, %nargin] = argn(0);
    
    obj = findobj("Tag", r.name);
    if ~isempty(obj) then
        parenth = get(obj, "Parent");
        error("rt_drivebot g.u.i. (" + sci2exp(parenth) + ") already drives the """ + r.name + """ robot.");
    end
    
	global margin_x;
	global margin_y;
	
	global padding_x;
	global padding_y;
	
	global frame_w;
	global frame_h;
	
//	global plot_w;
//	global plot_h;
	
	// Parameters
	// =========================================================================
	
	frame_w            = 300;     // Frame width
	frame_h            = 550;     // Frame height
	
//	plot_w             = 300;     // Plot width
//	plot_h             = frame_h; // Plot height
	
	margin_x           = 15;      // Horizontal margin between each elements
	margin_y           = 15;      // Vertical margin between each elements
	
	padding_x          = 10;      // Horizontal padding between each elements
	padding_y          = 10;      // Vertical padding between each elements
	
	button_w           = 100;     // Button width
	button_h           = 30;      // Button height
	
	defaultfont        = "arial"; // Default Font
	subframe_font_size = 12;      // Title font size (Rotation angle, Colormap, ...)
	text_font_size     = 11;      // Text font size
	

    bgcol = [135 206 250]/255;
    h_xyzatext = [];
    h_slider = [];
    h_edit = [];
    n = r.n;
    minVal = -%pi;
    maxVal = %pi;
    scale = 100/%pi*ones(n, 1);
    escale = ones(n, 1);
    rplot_id = [];
    width = 300;
    height = 40;
    // figure props.
    width_fig = (width+5)*0.8+(width+5)*0.2+50; height_fig = height*(n+2);
    // text prop. (qi: )
    width_textqi = width*0.1; height_textqi = height*0.4;
    // sliders props.
    width_sli = width*0.7; height_sli = height*0.4;
    // edit props.
    width_ed = (width+5)*0.25; height_ed = height*0.4+4;
    // xyzatext props.
    width_xyza = width*0.25; height_xyza = height/2;

    qlim = []//r.qlim;
    if isempty(qlim),
        qlim = [minVal*ones(n, 1) maxVal*ones(n, 1)];
    end

    if (%nargin == 2) & (typeof(b) == "string") then
        if part(b, [1,2,3]) == "deg" then
            disp("** in degree mode **");
            L = r.links;
            for i = 1:r.n,
                if L(i).RP == "R" then
                    escale(i) = 180/%pi;
                end
            end
        end
        // else rad. mode
    end


	// Figure creation
	// ========================================================================= 
	
	axes_w       = 2*margin_x + frame_w ; // axes width
	axes_h       = 2*margin_y + frame_h;          // axes height (100 => toolbar height)
	
	fig = scf(100001);
	

	fig.background      = -2;
	fig.color_map       = jetcolormap(128);
	fig.figure_position = [0 0];
	fig.figure_name     = gettext("Control Plot3d");
	
	// New menu
	
	
	fig.axes_size       = [axes_w axes_h];
	set(fig, "figure_name", "rt_drivebot g.u.i. (" + sci2exp(fig) + ")");
    
    
    
    
    	// Plot3d creation
	// =========================================================================
    /////////////////////
    // figure creation //
    /////////////////////
//    fig = figure(   "Position", [0, 0, width_fig, height_fig],..
//                    "BackgroundColor", bgcol);
//    set(fig, "figure_name", "rt_drivebot g.u.i. (" + sci2exp(fig) + ")");
    /////////////////////////////////////////////////////////////////
    // first we check to see if there are any graphical robots of  //
    // this name, if so we use them, otherwise create a robot plot.//
    /////////////////////////////////////////////////////////////////
    rh = rt_findtag(r.name);
    if ~isempty(rh) then
        ud = rh(1).user_data;
        r = ud(2);
        if %nargin < 2 then
            q = r.q.';
        else
            q = b;
            plot(r, q);
        end
        rplot_id = r.handles.robot.parent.parent.figure_id;
    else
        cfhdb = scf();
        drawlater();
        rplot_id = cfhdb.figure_id;
        cfhdb.pixmap = "on";
        cfhdb.children.tight_limits = "on";
        cfhdb.children.rotation_angles = [80, -46];
        if %nargin < 2 then
            q = zeros(1, n);
        else
            q = b;
        end
        
        plot(r, q);
        
        drawnow();
    end
    
	// Frames creation [Control Panel]
	// =========================================================================
	
	my_frame = uicontrol( fig,...
		"relief"              , "groove",...
		"style"               , "frame",...
		"units"               , "pixels",...
		"position"            , [ margin_x margin_y frame_w frame_h],...
		"horizontalalignment" , "center", ...
		"background"          , [1 1 1], ...
		"tag"                 , "frame_control" ...
	);
	
	// Frame title
	my_frame_title = uicontrol( fig,...
		"style"               , "text",...
		"string"              , "Control Panel",...
		"units"               , "pixels",...
		"position"            , [ 30+margin_x margin_y+frame_h-10 frame_w-60 20 ],...
		"fontname"            , defaultfont,...
		"fontunits"           , "points",...
		"fontsize"            , 16,...
		"horizontalalignment" , "center", ...
		"background"          , [1 1 1], ...
		"tag"                 , "title_frame_control" ...
	);
	
	
	// Rotation Angle
	// =========================================================================
	
	my_slider_angle = 0;
	
	my_ra_frame_w     = frame_w-2*padding_x
	my_ra_frame_h     = 50;
	my_ra_frame_pos_x = padding_x+margin_x;
	my_ra_frame_pos_y = (margin_y+frame_h) - 4*padding_y - my_ra_frame_h;
	
	my_slider_width      = my_ra_frame_w - 20;
	my_slider_height     = 20;
	my_slider_position_x = my_ra_frame_pos_x + 10;
	my_slider_position_y = my_ra_frame_pos_y + 10;
    my_slider_position_y2 = my_ra_frame_pos_y + 40;
	
	// frame
	
	my_ra_frame = uicontrol(  fig,...
		"relief"              , "groove",...
		"style"               , "frame",...
		"units"               , "pixels",...
		"position"            , [ my_ra_frame_pos_x my_ra_frame_pos_y my_ra_frame_w my_ra_frame_h],...
		"horizontalalignment" , "center", ...
		"background"          , [1 1 1], ...
		"tag"                 , "frame_control" ...
	);
	
	// Frame title
	
	my_ra_frame_title = uicontrol(  fig,...
		"style"               , "text",...
		"string"              , "Rotation angle",...
		"units"               , "pixels",...
		"position"            , [ 70+my_ra_frame_pos_x my_ra_frame_pos_y+my_ra_frame_h-9 my_ra_frame_w-140 18 ],...
		"fontname"            , defaultfont,...
		"fontunits"           , "points",...
		"fontsize"            , subframe_font_size,...
		"horizontalalignment" , "center", ...
		"background"          , [1 1 1], ...
		"tag"                 , "title_frame_control" ...
	);
	
	my_slider_angle = uicontrol( fig,...
		"style"               , "slider",...
		"Min"                 , 0,...
		"Max"                 , 360,...
		"Value"               , 70,...
		"SliderStep"          , [2 30],...
		"units"               , "pixels",...
		"position"            , [ my_slider_position_x my_slider_position_y my_slider_width my_slider_height ],...
		"tag"                 , "slider_angle", ...
		"callback"            , "update_plot3d_angle()" ...
	);
	
	
	//Frame che contiene gli slider per i link
	my_link_frame = uicontrol( fig,...
		"relief"              , "groove",...
		"style"               , "frame",...
		"units"               , "pixels",...
		"position"            , [ my_ra_frame_pos_x my_ra_frame_pos_y-330 my_ra_frame_w my_ra_frame_h+250],...
		"horizontalalignment" , "center", ...
		"background"          , [1 1 1], ...
		"tag"                 , "link_frame_control" ...
	);


    h_whichrobot = uicontrol(fig, "Style", "text",..
                                "Units", "pixels",..
                                "fontsize", 12,..
                                "fontname", defaultfont,...
                                "fontunits", "points",...
                                "Horizontalalignment", "center",..
                                "Position", [ my_slider_position_x-10 my_slider_position_y-40 280 my_slider_height ],..
                                "BackgroundColor", [1, 0.2, 0.3],..
                                "Tag", r.name,..                            // useful var when executing callbacks
                                "Userdata", [scale; escale; rplot_id],..    // another useful var
                                "String", r.name);                          // last useful var
                                
qualerobot=h_whichrobot.String;
count=1;
for i=1:n,
    h_slider(i) = uicontrol( fig,...
		"style"               , "slider",...
        "Min"                 , scale(i)*qlim(i,1),...
        "Max"                 , scale(i)*qlim(i,2),...
        "Value"               , scale(i)*q(i),...
		"SliderStep"          , [2 30],...
		"units"               , "pixels",...
        "enable"              , "on",...
		"position"            , [ my_slider_position_x my_slider_position_y-50-(40*i) my_slider_width my_slider_height ],...
		"tag"                 , "hslider" + sci2exp(i)); ...
		set(h_slider(i), "Callback", "drivelink("+sci2exp(i)+","""+qualerobot+"'","""+sci2exp(count)+""")"); ...
//       disp(sci2exp(i));
        //set(h_slider(i), "Callback", "rt_drivebotcb1(get(" + sci2exp(h_whichrobot) + ",''String''))");
//	my_slider_angle = uicontrol( ...
//		"parent"              , demo_plot3d,...
//		"style"               , "slider",...
//		"Min"                 , 0,...
//		"Max"                 , 360,...
//		"Value"               , 70,...
//		"SliderStep"          , [2 30],...
//		"units"               , "pixels",...
//		"position"            , [ my_slider_position_x my_slider_position_y+300 my_slider_width my_slider_height ],...
//		"tag"                 , "hslider" + sci2exp(i), ...
//		"callback"            , "update_plot3d_angle()" ...
//	);
end
endfunction



	
	


function update_plot3d_angle()
	
	my_plot_axes = gca();
	my_new_angle = get(gcbo,"Value");
	
	if( my_new_angle>0 & my_new_angle<360 ) then
		my_plot_axes.rotation_angles(2) = my_new_angle;
	end
	
endfunction


function drivelink(i,name,count)
    //disp(count);
    tol = 1e-10;
    //disp(name);
    //disp(i);
    obj = findobj("Tag", name);   // because i'm here, it does exist surely
    //disp(obj);
    fig = get(obj, "Parent");
    disp(obj.user_data); //deve essere "Figure"
    abort;
    rh = findobj("Tag", name);
    disp(rh.user_data)
    set(obj, "enable", "off");
    enable = get(obj,"enable");
    disp(enable); 
    
    ud = rh(1).userdata;
    //disp(ud(1));
    rr = ud(2);
    n = rr.n;
    //disp(n);
    //disp(rr);
    
     q = [];
     
    user_d=obj.userdata;
    ////execstr("global " + user_d(1));
    //execstr("global " + user_d(2));
    //execstr("global " + user_d(3));
    //gui_ud = evstr(get(obj, "Userdata"));
    gui_ud = user_d;
    disp(n)
    scale = gui_ud(1:n);
    escale = gui_ud(n+1:2*n);
    rplot_id = gui_ud($);
    
     // get value from sliders
    for j = 1:n,
        objslider_j = findobj("Tag", "hslider" + sci2exp(j));
        sli_val = get(objslider_j, "Value");
        if abs(sli_val) < tol then
            q(j) = 0;
        else
            q(j) = sli_val/scale(j);
        end
        //disp(sli_val);
        //objedit_j = findobj("Tag", "hedit" + sci2exp(j) + "_" + sci2exp(fig));
        //set(objedit_j, "String", "escalechenonva");//sci2exp(escale(j)*q(j)));
    end
    realtimeinit(0.04);
    scf(rplot_id);

    drawlater();//--------------------OOOOOOOOOOOO

        plot(rr, q.');
    drawnow();


//--------------------OOOOOOOOOOOO
//    t6 = rt_fkine(rr, q);
//    for i = 1:3,
//        objxyza1 = findobj("Tag", "hxyzatext" + sci2exp(i) + "1_" + sci2exp(fig));
//        set(objxyza1, "String", sci2exp(t6(i,4)));
//        objxyza2 = findobj("Tag", "hxyzatext" + sci2exp(i) + "2_" + sci2exp(fig));
//        set(objxyza2, "String", sci2exp(t6(i,3)));
//    end
    
endfunction
