//  Copyright (C) 2014-20 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function [h] = ishomog(tr,rtest)
    // Test if argument is a homogeneous transformation
    //
    // Calling Sequence
    // ishomog(T) 
    // ishomog(T, "valid")
    //
    // Description
    // ISHOMOG(T) is true (1) if the argument T is of dimension 4x4 or 4x4xN, else 
    // false (0).
    // 
    // ISHOMOG(T, 'valid') as above, but also checks the validity of the rotation
    // matrix.
    // 
    // <refsection>
    // <title>Notes</title>
    // <itemizedlist>
    // <listitem><para>The first form is a fast, but incomplete, test for a transform in SE(3)</para></listitem>
    // <listitem><para>Does not work for the SE(2) case</para></listitem>
    // </itemizedlist>
    // </refsection>
    // 
    // See also 
    // isrot
    // isvec
    //
    // Authors
    // Copyright (C) 1993-2011 - Peter I. Corke
    // Copyright (C) 2014-20 - Davide Cappucci

    [%nargout,%nargin] = argn(0);
    h=[];
    d=size(tr)
    if size(size(tr),"*")>=2 then
        // ! L.36: abs(d(1:2)==[4,4]) potrebbe essere sostituito da:
        // !    --> d(1:2)==[4,4] se d(1:2)==[4,4] è reale
        h = and(d(1:2)==[4,4]);

        %v03 = %f;  
        if h then 
            %v03 = %nargin>1;
        end
        if %v03 then
            h = abs(det(tr(1:3,1:3))-1)<%eps;
        end

    else
        h = %f;
    end
endfunction
