//  Copyright (C) 2014-20 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function it = itorque(robot, q, qdd)
    // Inertia torque
    //
    // Calling Sequence
    // TAUI = itorque(R, Q, QDD)
    //
    // Description
    // TAUI = ITORQUE(R, Q, QDD) is the inertia force/torque vector (1xN) at the 
    // specified joint configuration Q (1xN) and acceleration QDD (1xN), that is,
    // TAUI = INERTIA(R, Q)*QDD.
    //
    // If Q and QDD are matrices (KxN), each row is interpreted as a joint state 
    // vector, and the result is a matrix (KxN) where each row is the corresponding
    // joint torques.
    //
    // <refsection>
    // <title>Notes</title>
    // <itemizedlist>
    // <listitem><para>If the robot model contains non-zero motor inertia
    // then this will included in the result.</para></listitem>
    // </itemizedlist>
    // </refsection> 
    //
    // See also 
    // rne
    // inertia
    //
    // Authors
    // Copyright (C) 1993-2011 - Peter I. Corke
    // Copyright (C) 2014-20 - Davide Cappucci

    it = rne(robot, q, zeros(size(q,1),size(q,2)), qdd, [0;0;0]);
endfunction
