/*  Copyright (C) 2020 - Corrado Guarino Lo Bianco
*
*  This file is part of the Robotics Toolbox for Scilab.
*
*  Robotics Toolbox is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  Robotics Toolbox is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*
*  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
*  by Peter Corke.
*/

#include <math.h> /* atan2 */
#include <float.h> /* DBL_EPSILON */

int r2rpy(double *t, double *roll, double *pitch, double *yaw)
{

	double sr, cr;

    if (fabs(t[0]) < DBL_EPSILON & fabs(t[1]) < DBL_EPSILON)
    {
        // singularity
        *roll = 0.0; // roll is zero
        *pitch = atan2(-t[6], 0.0); // pitch
        *yaw = atan2(-t[5], t[4]); // yaw is difference yaw-roll
    }
    else
    {
        *roll = atan2(t[1], t[0]); //roll
        *pitch = atan2(-t[2], cr*t[0] + sr*t[1]); //pitch
        *yaw = atan2(sr*t[6] - cr*t[7], cr*t[4] - sr*t[3]); //yaw
    } 
      
    return 0;
}


